package java.awt;

import java.awt.peer.LightweightPeer;
import sun.awt.SunGraphicsCallback;

abstract class GraphicsCallback extends SunGraphicsCallback
{
    GraphicsCallback() {
    }
    
    static final class PaintCallback extends GraphicsCallback
    {
        private static GraphicsCallback.PaintCallback instance;
        
        private PaintCallback() {
        }
        
        @Override
        public void run(Component component, Graphics graphics) {
            component.paint(graphics);
        }
        
        static GraphicsCallback.PaintCallback getInstance() {
            return GraphicsCallback.PaintCallback.instance;
        }
        
        static {
            GraphicsCallback.PaintCallback.instance = new GraphicsCallback.PaintCallback();
        }
    }
    
    static final class PrintCallback extends GraphicsCallback
    {
        private static GraphicsCallback.PrintCallback instance;
        
        private PrintCallback() {
        }
        
        @Override
        public void run(Component component, Graphics graphics) {
            component.print(graphics);
        }
        
        static GraphicsCallback.PrintCallback getInstance() {
            return GraphicsCallback.PrintCallback.instance;
        }
        
        static {
            GraphicsCallback.PrintCallback.instance = new GraphicsCallback.PrintCallback();
        }
    }
    
    static final class PaintAllCallback extends GraphicsCallback
    {
        private static GraphicsCallback.PaintAllCallback instance;
        
        private PaintAllCallback() {
        }
        
        @Override
        public void run(Component component, Graphics graphics) {
            component.paintAll(graphics);
        }
        
        static GraphicsCallback.PaintAllCallback getInstance() {
            return GraphicsCallback.PaintAllCallback.instance;
        }
        
        static {
            GraphicsCallback.PaintAllCallback.instance = new GraphicsCallback.PaintAllCallback();
        }
    }
    
    static final class PrintAllCallback extends GraphicsCallback
    {
        private static GraphicsCallback.PrintAllCallback instance;
        
        private PrintAllCallback() {
        }
        
        @Override
        public void run(Component component, Graphics graphics) {
            component.printAll(graphics);
        }
        
        static GraphicsCallback.PrintAllCallback getInstance() {
            return GraphicsCallback.PrintAllCallback.instance;
        }
        
        static {
            GraphicsCallback.PrintAllCallback.instance = new GraphicsCallback.PrintAllCallback();
        }
    }
    
    static final class PeerPaintCallback extends GraphicsCallback
    {
        private static GraphicsCallback.PeerPaintCallback instance;
        
        private PeerPaintCallback() {
        }
        
        @Override
        public void run(Component component, Graphics graphics) {
            component.validate();
            if ((component.peer instanceof LightweightPeer)) {
                component.lightweightPaint(graphics);
            }
            else {
                component.peer.paint(graphics);
            }
        }
        
        static GraphicsCallback.PeerPaintCallback getInstance() {
            return GraphicsCallback.PeerPaintCallback.instance;
        }
        
        static {
            GraphicsCallback.PeerPaintCallback.instance = new GraphicsCallback.PeerPaintCallback();
        }
    }
    
    static final class PeerPrintCallback extends GraphicsCallback
    {
        private static GraphicsCallback.PeerPrintCallback instance;
        
        private PeerPrintCallback() {
        }
        
        @Override
        public void run(Component component, Graphics graphics) {
            component.validate();
            if ((component.peer instanceof LightweightPeer)) {
                component.lightweightPrint(graphics);
            }
            else {
                component.peer.print(graphics);
            }
        }
        
        static GraphicsCallback.PeerPrintCallback getInstance() {
            return GraphicsCallback.PeerPrintCallback.instance;
        }
        
        static {
            GraphicsCallback.PeerPrintCallback.instance = new GraphicsCallback.PeerPrintCallback();
        }
    }
    
    static final class PaintHeavyweightComponentsCallback extends GraphicsCallback
    {
        private static GraphicsCallback.PaintHeavyweightComponentsCallback instance;
        
        private PaintHeavyweightComponentsCallback() {
        }
        
        @Override
        public void run(Component component, Graphics graphics) {
            if ((component.peer instanceof LightweightPeer)) {
                component.paintHeavyweightComponents(graphics);
            }
            else {
                component.paintAll(graphics);
            }
        }
        
        static GraphicsCallback.PaintHeavyweightComponentsCallback getInstance() {
            return GraphicsCallback.PaintHeavyweightComponentsCallback.instance;
        }
        
        static {
            GraphicsCallback.PaintHeavyweightComponentsCallback.instance = new GraphicsCallback.PaintHeavyweightComponentsCallback();
        }
    }
    
    static final class PrintHeavyweightComponentsCallback extends GraphicsCallback
    {
        private static GraphicsCallback.PrintHeavyweightComponentsCallback instance;
        
        private PrintHeavyweightComponentsCallback() {
        }
        
        @Override
        public void run(Component component, Graphics graphics) {
            if ((component.peer instanceof LightweightPeer)) {
                component.printHeavyweightComponents(graphics);
            }
            else {
                component.printAll(graphics);
            }
        }
        
        static GraphicsCallback.PrintHeavyweightComponentsCallback getInstance() {
            return GraphicsCallback.PrintHeavyweightComponentsCallback.instance;
        }
        
        static {
            GraphicsCallback.PrintHeavyweightComponentsCallback.instance = new GraphicsCallback.PrintHeavyweightComponentsCallback();
        }
    }
}
